@@ -3,7 +3,7 @@ package Thread::State;
 use strict;
 use warnings;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 require XSLoader;
 XSLoader::load('Thread::State', $VERSION);
@@ -57,6 +57,9 @@ Thread::State peeks at the ithread structures directly.
 
 You must use L<threads> before using Thread::State.
 
+This module requires  Perl core threads (<= 1.07) or
+CPAN threads (>= 1.23).
+
 =head1 METHODS
 
 All below methods can be used as class methods. In that case,
